package com.redhat.thermostat.tools.eclipse.plugin.wizards;

import java.io.IOException;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.ui.INewWizard;
import org.eclipse.ui.IWorkbench;

import com.redhat.thermostat.tools.eclipse.plugin.Activator;

public class ThermostatProjectCreationWizard extends Wizard implements INewWizard {

    private ThermostatProjectCreationWizardPage pageOne;

    @Override
    public void init(IWorkbench workbench, IStructuredSelection selection) {
        setWindowTitle("Create New Thermostat Plugin");
        setNeedsProgressMonitor(true);
    }

    @Override
    public void addPages() {
        pageOne = new ThermostatProjectCreationWizardPage();
        addPage(pageOne);
    }

    @Override
    public boolean performFinish() {
        try {
            String groupId = pageOne.getGroupId();
            String artifactId = pageOne.getArtifactId();
            String version = pageOne.getVersion();

            String packagePrefix = pageOne.getPackagePrefix();
            String thermostatVersion = pageOne.getThermostatVersion();

            createProject(groupId, artifactId, version, packagePrefix, thermostatVersion);
        } catch (CoreException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }

        return true;
    }

    private void createProject(String groupId, String artifactId, String version, String packagePrefix, String thermostatVersion) throws CoreException {
        ProjectCreator creator = new ProjectCreator(groupId, artifactId, version, packagePrefix, thermostatVersion);
        try {
            creator.create();
        } catch (IOException e) {
            throw new CoreException(new Status(Status.ERROR, Activator.PLUGIN_ID, "Error creating project", e));
        }
    }

}
